@@ -78,10 +78,10 @@ GtkWidget *personal_menu_button_new(int padding)
 static void execute_command(GtkMenuItem *item, gint index)
 {
 	pid_t pid;
-	gchar *appName;
-	gchar *iconName;
-	gchar *executable;
-	gchar *service;
+	gchar *appName=NULL;
+	gchar *iconName=NULL;
+	gchar *executable=NULL;
+	gchar *service=NULL;
 	gboolean termFlag,rootFlag;
 	gint argc;
 	gchar** argv;
@@ -91,13 +91,12 @@ static void execute_command(GtkMenuItem *item, gint index)
 	GKeyFile* keyFile;
 	GError *error=NULL;
 	gboolean result;
-
+	
 	if (index>=0)
 	{
 		snprintf(entry,5,"%d",index);
 		keyFile=g_key_file_new();
-		filename=g_strdup(HOME_DIR);
-		filename=g_strconcat(filename,"/.personal_menu.rc",NULL);
+		filename=g_build_filename(HOME_DIR,"/.personal_menu.rc",NULL);
 		fileExists=g_key_file_load_from_file(keyFile,filename,G_KEY_FILE_KEEP_COMMENTS,NULL);
 		if (fileExists)
 		{
@@ -109,77 +108,86 @@ static void execute_command(GtkMenuItem *item, gint index)
 			service=g_key_file_get_string(keyFile,entry,"service",NULL);
 		}
 		g_key_file_free(keyFile);
-	}
-	else
-	{
-		appName="Edit Menu";
-		iconName="personal-menu";
 		
-		osso_context_t *osso=osso_initialize("personal-menu-launch","0.5",TRUE,NULL);
-		osso_return_t retVal;
-
-		retVal=osso_rpc_async_run(osso,"com.nokia.controlpanel","/com/nokia/controlpanel/rpc","com.nokia.controlpanel","run_applet",NULL,NULL,DBUS_TYPE_STRING,"libpersonalmenusetup.so",DBUS_TYPE_BOOLEAN,TRUE,DBUS_TYPE_INVALID);
-		if (retVal==OSSO_OK)
+		if (rootFlag)
 		{
-			char buf[64];
-			g_snprintf(buf, 64, "%s started",appName);
-			hildon_banner_show_information(NULL, iconName, buf);
+			FILE *fp=NULL;
+			fp=fopen("/usr/bin/rootsh","rb");
+			if (fp!=NULL)
+			{
+				fclose(fp);
+				executable=g_strconcat("rootsh ",executable,NULL);
+			}
+			else
+				executable=g_strconcat("sudo ",executable,NULL);
 		}
-		else
+		
+		if (termFlag)
 		{
-			hildon_banner_show_information(NULL, "qgn_note_gene_syserror", "Execution failed");
-		}
-		osso_deinitialize(osso);
-		return;
-	}
-
-	if (rootFlag)
-	{
-		executable=g_strconcat("sudo ",executable,NULL);
-	}
-
-	if (termFlag)
-	{
-		osso_context_t *osso=osso_initialize("personal-menu-launch","0.5",TRUE,NULL);
-		osso_return_t retVal;
-	
-		executable = g_strconcat("sh -c \"", g_strescape(executable, NULL), " ; read x\"", NULL);
-
-		retVal=osso_rpc_async_run(osso,"com.nokia.xterm","/com/nokia/xterm","com.nokia.xterm","run_command",NULL,NULL,DBUS_TYPE_STRING,executable,DBUS_TYPE_INVALID);
-		if (retVal==OSSO_OK)
-		{
-			char buf[64];
-			g_snprintf(buf, 64, "%s started",appName);
-			hildon_banner_show_information(NULL, iconName, buf);
-		}
-		else
-		{
-			hildon_banner_show_information(NULL, "qgn_note_gene_syserror", "Execution failed");
-		}
-		osso_deinitialize(osso);
-	}
-	else 
-	{
-		osso_context_t *osso=osso_initialize("personal-menu-launch","0.5",TRUE,NULL);
-		if ((g_strcasecmp(service,"")==0) || !(result = osso_rpc_run_with_defaults(osso, service, "top_application", NULL, DBUS_TYPE_INVALID) == OSSO_OK))
-		{
-			if (g_shell_parse_argv(executable,&argc,&argv,NULL))
-				g_spawn_async(NULL,argv,NULL,(GSpawnFlags)G_SPAWN_SEARCH_PATH,NULL,NULL,&pid,&error);
-			if (!error)
+			osso_context_t *osso=osso_initialize("personal-menu-launch","0.5",TRUE,NULL);
+			osso_return_t retVal;
+			
+			executable = g_strconcat("sh -c \"", g_strescape(executable, NULL), " ; read x\"", NULL);
+			
+			retVal=osso_rpc_async_run(osso,"com.nokia.xterm","/com/nokia/xterm","com.nokia.xterm","run_command",NULL,NULL,DBUS_TYPE_STRING,executable,DBUS_TYPE_INVALID);
+			if (retVal==OSSO_OK)
 			{
 				char buf[64];
 				g_snprintf(buf, 64, "%s started",appName);
 				hildon_banner_show_information(NULL, iconName, buf);
-				/*free(buf);*/
 			}
-			if (error)
+			else
 			{
 				hildon_banner_show_information(NULL, "qgn_note_gene_syserror", "Execution failed");
-				g_error_free(error);
 			}
+			osso_deinitialize(osso);
 		}
+		else 
+		{
+			osso_context_t *osso=osso_initialize("personal-menu-launch","0.5",TRUE,NULL);
+			if ((g_strcasecmp(service,"")==0) || !(result = osso_rpc_run_with_defaults(osso, service, "top_application", NULL, DBUS_TYPE_INVALID) == OSSO_OK))
+			{
+				if (g_shell_parse_argv(executable,&argc,&argv,NULL))
+				{
+					g_spawn_async(NULL,argv,NULL,(GSpawnFlags)G_SPAWN_SEARCH_PATH,NULL,NULL,&pid,&error);
+					g_strfreev(argv);
+				}
+				if (!error)
+				{
+					char buf[64];
+					g_snprintf(buf, 64, "%s started",appName);
+					hildon_banner_show_information(NULL, iconName, buf);
+					/*free(buf);*/
+				}
+				if (error)
+				{
+					hildon_banner_show_information(NULL, "qgn_note_gene_syserror", "Execution failed");
+					g_error_free(error);
+				}
+			}
+			osso_deinitialize(osso);
+		}
+		g_free(filename);
+	}
+	else
+	{
+		osso_context_t *osso;
+		
+		osso=osso_initialize("personal-menu","0.9",TRUE,NULL);
+		osso_rpc_async_run(osso,
+			"com.nokia.personalmenuhelper",
+			"/com/nokia/personalmenuhelper",
+			"com.nokia.personalmenuhelper",
+			"top_application", NULL,NULL,
+			DBUS_TYPE_STRING,"settings",
+			DBUS_TYPE_INVALID);
+			
 		osso_deinitialize(osso);
 	}
+	g_free(appName);
+	g_free(iconName);
+	g_free(executable);
+	g_free(service);
 }
 
 static void get_workarea(GtkAllocation *allocation)
@@ -330,6 +338,13 @@ popup_menu (GtkWidget *button, PersonalMenuNavigatorPlugin *plugin)
 {
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(plugin->button)))
 	{
+		gint width,height;
+		GtkAllocation workarea={0,0,0,0};
+		get_workarea(&workarea);
+		if ((plugin->width!=workarea.width)||(plugin->height!=workarea.height))
+		{
+			create_menu(plugin);
+		}
 		gtk_menu_popup (GTK_MENU (plugin->menu),NULL,NULL,(GtkMenuPositionFunc)menu_position,plugin,0,gtk_get_current_event_time());
 		plugin->popped=TRUE;
 	}
@@ -347,232 +362,258 @@ static gboolean header_activate(GtkWidget *widget, GdkEventButton *event, gpoint
 
 static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 {
-    GtkWidget  *menu_item;
-    GdkPixbuf  *icon;
-    GtkIconTheme *icon_theme;
-    GtkWidget   *icon_image;
-    gchar* filename;
-    gboolean fileExists;
-    GKeyFile* keyFile;
-    GtkAllocation workarea={0,0,0,0};
+	GtkWidget  *menu_item;
+	GdkPixbuf  *icon;
+	GtkIconTheme *icon_theme;
+	GtkWidget   *icon_image;
+	gchar* filename;
+	gboolean fileExists;
+	GKeyFile* keyFile;
+	GtkAllocation workarea={0,0,0,0};
 
-    if (GTK_IS_MENU(plugin->menu))
-	gtk_widget_destroy(plugin->menu);
-    plugin->menu = gtk_menu_new ();
+	if (GTK_IS_MENU(plugin->menu))
+		gtk_widget_destroy(plugin->menu);
+	plugin->menu = gtk_menu_new ();
 
-    keyFile=g_key_file_new();
-    filename=g_strdup(HOME_DIR);
-    filename=g_strconcat(filename,"/.personal_menu.rc",NULL);
-    fileExists=g_key_file_load_from_file(keyFile,filename,G_KEY_FILE_KEEP_COMMENTS,NULL);
-    if (fileExists)
-    {
-      int i=0;
-      int x=0;
-      int y=0;
-      int iconSize=40;
-      int minRows=8;
-      int numCols=4;
-      int entryPerColumn;
-      gchar *colourString;
-      gchar *fontString;
-      gboolean systemBool;
-      gchar *headerColourString;
-      gchar *headerFontString;
-      gboolean headerSystemBool;
-      gboolean layoutBool;
-      gsize numEntry;
-      GError *error=NULL;
-      gchar **retVal=g_key_file_get_groups(keyFile,&numEntry);
-      char entry[5];
-      gboolean found;
-      g_strfreev(retVal);
+	keyFile=g_key_file_new();
+	filename=g_strdup(HOME_DIR);
+	filename=g_strconcat(filename,"/.personal_menu.rc",NULL);
+	fileExists=g_key_file_load_from_file(keyFile,filename,G_KEY_FILE_KEEP_COMMENTS,NULL);
+	if (fileExists)
+	{
+		int i=0;
+		int x=0;
+		int y=0;
+		int iconSize=40;
+		int minRows=8;
+		int numCols=4;
+		int entryPerColumn;
+		gchar *colourString;
+		gchar *fontString;
+		gboolean systemBool;
+		gchar *headerColourString;
+		gchar *headerFontString;
+		gboolean headerSystemBool;
+		gboolean layoutBool;
+		gsize numEntry;
+		GError *error=NULL;
+		gchar **retVal=g_key_file_get_groups(keyFile,&numEntry);
+		char entry[5];
+		gboolean found;
+		g_strfreev(retVal);
 
-      get_workarea(&workarea);
-      
-	numEntry--;
-	iconSize=g_key_file_get_integer(keyFile,"config","icon size",&error);
-	if (error)
-	{
-		iconSize=40;
-		g_error_free(error);
-		error=NULL;
-	}
-	colourString=g_key_file_get_string(keyFile,"config","font colour",&error);
-	if (error)
-	{
-		colourString="000000000000";
-		g_error_free(error);
-		error=NULL;
-	}
-	headerColourString=g_key_file_get_string(keyFile,"config","header font colour",&error);
-	if (error)
-	{
-		headerColourString="000000000000";
-		g_error_free(error);
-		error=NULL;
-	}
-	fontString=g_key_file_get_string(keyFile,"config","font style",&error);
-	if (error)
-	{
-		fontString="Sans 14";
-		g_error_free(error);
-		error=NULL;
-	}
-	headerFontString=g_key_file_get_string(keyFile,"config","header font style",&error);
-	if (error)
-	{
-		headerFontString="Sans 14";
-		g_error_free(error);
-		error=NULL;
-	}
-	systemBool=g_key_file_get_boolean(keyFile,"config","system style",&error);
-	if (error)
-	{
-		systemBool=TRUE;
-		g_error_free(error);
-		error=NULL;
-	}
-	headerSystemBool=g_key_file_get_boolean(keyFile,"config","header system style",&error);
-	if (error)
-	{
-		headerSystemBool=TRUE;
-		g_error_free(error);
-		error=NULL;
-	}
-	layoutBool=g_key_file_get_boolean(keyFile,"config","auto layout",&error);
-	if (error)
-	{
-		layoutBool=TRUE;
-		g_error_free(error);
-		error=NULL;
-	}
-	if (!layoutBool)
-	{
-		minRows=g_key_file_get_integer(keyFile,"config","num rows",&error);
+		get_workarea(&workarea);
+
+		numEntry--;
+		iconSize=g_key_file_get_integer(keyFile,"config","icon size",&error);
 		if (error)
 		{
-			minRows=8;
+			iconSize=40;
 			g_error_free(error);
 			error=NULL;
 		}
-		numCols=g_key_file_get_integer(keyFile,"config","num cols",&error);
+		colourString=g_key_file_get_string(keyFile,"config","font colour",&error);
 		if (error)
 		{
-			numCols=4;
+			colourString="000000000000";
 			g_error_free(error);
 			error=NULL;
 		}
-	}
-	else
-	{
-		if (iconSize!=0)
-			minRows=(workarea.height-64)/(iconSize+2);
+		headerColourString=g_key_file_get_string(keyFile,"config","header font colour",&error);
+		if (error)
+		{
+			headerColourString="000000000000";
+			g_error_free(error);
+			error=NULL;
+		}
+		fontString=g_key_file_get_string(keyFile,"config","font style",&error);
+		if (error)
+		{
+			fontString="Sans 14";
+			g_error_free(error);
+			error=NULL;
+		}
+		headerFontString=g_key_file_get_string(keyFile,"config","header font style",&error);
+		if (error)
+		{
+			headerFontString="Sans 14";
+			g_error_free(error);
+			error=NULL;
+		}
+		systemBool=g_key_file_get_boolean(keyFile,"config","system style",&error);
+		if (error)
+		{
+			systemBool=TRUE;
+			g_error_free(error);
+			error=NULL;
+		}
+		headerSystemBool=g_key_file_get_boolean(keyFile,"config","header system style",&error);
+		if (error)
+		{
+			headerSystemBool=TRUE;
+			g_error_free(error);
+			error=NULL;
+		}
+		layoutBool=g_key_file_get_boolean(keyFile,"config","auto layout",&error);
+		if (error)
+		{
+			layoutBool=TRUE;
+			g_error_free(error);
+			error=NULL;
+		}
+		if (!layoutBool)
+		{
+			minRows=g_key_file_get_integer(keyFile,"config","num rows",&error);
+			if (error)
+			{
+				minRows=8;
+				g_error_free(error);
+				error=NULL;
+			}
+			numCols=g_key_file_get_integer(keyFile,"config","num cols",&error);
+			if (error)
+			{
+				numCols=4;
+				g_error_free(error);
+				error=NULL;
+			}
+		}
 		else
 		{
-			GtkStyle *style=gtk_rc_get_style(GTK_WIDGET(plugin));
-			PangoFontDescription *font=style->font_desc;
-			gint fontSize=pango_font_description_get_size(font);
-			if (!pango_font_description_get_size_is_absolute(font))
-				fontSize=fontSize/(PANGO_SCALE);
-			minRows=(workarea.height-64)/(fontSize+10);
+			if (iconSize!=0)
+				minRows=(workarea.height-64)/(iconSize+2);
+			else
+			{
+				GtkStyle *style=gtk_rc_get_style(GTK_WIDGET(plugin));
+				PangoFontDescription *font=style->font_desc;
+				gint fontSize=pango_font_description_get_size(font);
+				if (!pango_font_description_get_size_is_absolute(font))
+					fontSize=fontSize/(PANGO_SCALE);
+				minRows=(workarea.height-64)/(fontSize+10);
+			}
 		}
-	}
-	entryPerColumn=minRows;
+		entryPerColumn=minRows;
 
-	if (numEntry>(minRows)*numCols)
-	{
-		entryPerColumn=numEntry/numCols;
-		if (numEntry%numCols>0)
-			entryPerColumn++;
-	}
-      snprintf(entry,5,"%d",i);
-      found=g_key_file_has_group(keyFile,entry);
-      while (found)
-      {
-	gchar* appName;
-	gchar* iconName;
-	gchar* executable=NULL;
-
-	sprintf(entry,"%d",i);
-	appName=g_key_file_get_string(keyFile,entry,"app name",NULL);
-	iconName=g_key_file_get_string(keyFile,entry,"icon name",NULL);
-	executable=g_key_file_get_string(keyFile,entry,"executable",NULL);
-
-	if (executable!=NULL && g_strcasecmp(executable,"")!=0)
-	{
-		menu_item=gtk_image_menu_item_new_with_label(appName);
-		if (iconSize!=0)
+		if (numEntry>(minRows)*numCols)
 		{
+			entryPerColumn=numEntry/numCols;
+			if (numEntry%numCols>0)
+				entryPerColumn++;
+		}
+		snprintf(entry,5,"%d",i);
+		found=g_key_file_has_group(keyFile,entry);
+		while (found)
+		{
+			gchar* appName;
+			gchar* iconName;
+			gchar* executable=NULL;
+
+			sprintf(entry,"%d",i);
+			appName=g_key_file_get_string(keyFile,entry,"app name",NULL);
+			iconName=g_key_file_get_string(keyFile,entry,"icon name",NULL);
+			executable=g_key_file_get_string(keyFile,entry,"executable",NULL);
+
+			if (g_strcasecmp(appName,"(SEPARATOR)")==0)
+			{
+				menu_item=gtk_menu_item_new();
+				g_signal_connect(G_OBJECT(menu_item),"select",G_CALLBACK(header_select),NULL);
+				g_signal_connect(G_OBJECT(menu_item),"button-release-event",G_CALLBACK(header_activate),NULL);
+			}
+			else if (executable!=NULL && g_strcasecmp(executable,"")!=0)
+			{
+				menu_item=gtk_image_menu_item_new_with_label(appName);
+				if (iconSize!=0)
+				{
+					gint width,height;
+					icon_theme = gtk_icon_theme_get_default ();
+					icon=gtk_icon_theme_load_icon(icon_theme,iconName,iconSize,0,NULL);
+					if (icon==NULL)
+					{
+						icon=gtk_icon_theme_load_icon(icon_theme,"qgn_list_gene_default_app",iconSize,0,NULL);
+					}
+					width=gdk_pixbuf_get_width(icon);
+					height=gdk_pixbuf_get_height(icon);
+					if ((width!=iconSize)&&(height!=iconSize))
+					{
+						if (width>height)
+						{
+							gint scale=(((gdouble)height/(gdouble)width)*iconSize);
+							icon=gdk_pixbuf_scale_simple(icon,iconSize,scale,GDK_INTERP_NEAREST);
+						}
+						else if (height>width)
+						{
+							gint scale=(((gdouble)width/(gdouble)height)*iconSize);
+							icon=gdk_pixbuf_scale_simple(icon,scale,iconSize,GDK_INTERP_NEAREST);
+						}
+						else
+						{
+							icon=gdk_pixbuf_scale_simple(icon,iconSize,iconSize,GDK_INTERP_NEAREST);
+						}
+					}
+					icon_image=gtk_image_new_from_pixbuf(icon);
+					g_object_unref(G_OBJECT(icon));
+					gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),icon_image);
+				}
+				if (!systemBool)
+					gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span font_desc='",fontString,"' foreground='#",colourString,"'>",gtk_label_get_label(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item)))),"</span>",NULL));
+					g_signal_connect(G_OBJECT(menu_item),"activate",G_CALLBACK(execute_command),i);
+				}
+				else
+				{
+					menu_item=gtk_menu_item_new_with_label(appName);
+					gtk_label_set_use_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),TRUE);
+					if (headerSystemBool)
+						gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span weight='bold'>",g_markup_escape_text(appName,-1),"</span>",NULL));
+					else
+						gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span font_desc='",headerFontString,"' foreground='#",headerColourString,"'>",g_markup_escape_text(appName,-1),"</span>",NULL));
+					g_signal_connect(G_OBJECT(menu_item),"select",G_CALLBACK(header_select),NULL);
+					g_signal_connect(G_OBJECT(menu_item),"button-release-event",G_CALLBACK(header_activate),NULL);
+				}
+
+				gtk_menu_attach(GTK_MENU(plugin->menu),menu_item,x,x+1,y,y+1);
+				y++;
+				if (y>entryPerColumn-1)
+				{
+					y=0;
+					x++;
+				}
+				snprintf(entry,5,"%d",++i);
+				found=g_key_file_has_group(keyFile,entry);
+				g_free(appName);
+				g_free(iconName);
+				g_free(executable);
+			}
+		}
+		else
+		{
+			menu_item=gtk_image_menu_item_new_with_label("Create your personal menu!");
 			icon_theme = gtk_icon_theme_get_default ();
-			icon=gtk_icon_theme_load_icon(icon_theme,iconName,iconSize,0,NULL);
+			icon=gtk_icon_theme_load_icon(icon_theme,"personal-menu",40,0,NULL);
 			if (icon==NULL)
 			{
-				icon=gtk_icon_theme_load_icon(icon_theme,"qgn_list_gene_default_app",iconSize,0,NULL);
+				icon=gtk_icon_theme_load_icon(icon_theme,"qgn_list_gene_default_app",40,0,NULL);
 			}
-			icon=gdk_pixbuf_scale_simple(icon,iconSize,iconSize,GDK_INTERP_NEAREST);
 			icon_image=gtk_image_new_from_pixbuf(icon);
 			g_object_unref(G_OBJECT(icon));
 			gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),icon_image);
+			g_signal_connect(G_OBJECT(menu_item),"activate",G_CALLBACK(execute_command),-1);
+			gtk_menu_append(GTK_MENU_SHELL(plugin->menu),menu_item);
 		}
-		if (!systemBool)
-			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span font_desc='",fontString,"' foreground='#",colourString,"'>",gtk_label_get_label(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item)))),"</span>",NULL));
-		g_signal_connect(G_OBJECT(menu_item),"activate",G_CALLBACK(execute_command),i);
-	}
-	else
-	{
-		menu_item=gtk_menu_item_new_with_label(appName);
-		gtk_label_set_use_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),TRUE);
-		if (headerSystemBool)
-			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span weight='bold'>",g_markup_escape_text(appName,-1),"</span>",NULL));
-		else
-			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span font_desc='",headerFontString,"' foreground='#",headerColourString,"'>",g_markup_escape_text(appName,-1),"</span>",NULL));
-		g_signal_connect(G_OBJECT(menu_item),"select",G_CALLBACK(header_select),NULL);
-		g_signal_connect(G_OBJECT(menu_item),"button-release-event",G_CALLBACK(header_activate),NULL);
-	}
+		g_key_file_free(keyFile);
 
+		/* Name the menu to get the appropriate theming */
+		gtk_widget_set_name (plugin->menu, "menu_from_navigator");
 
-	gtk_menu_attach(GTK_MENU(plugin->menu),menu_item,x,x+1,y,y+1);
-	y++;
-	if (y>entryPerColumn-1)
-	{
-		y=0;
-		x++;
-	}
-	snprintf(entry,5,"%d",++i);
-	found=g_key_file_has_group(keyFile,entry);
-	g_free(appName);
-	g_free(iconName);
-	g_free(executable);
-      }
-    }
-	else
-	{
-		menu_item=gtk_image_menu_item_new_with_label("Create your personal menu!");
-		icon_theme = gtk_icon_theme_get_default ();
-		icon=gtk_icon_theme_load_icon(icon_theme,"personal-menu",40,0,NULL);
-		if (icon==NULL)
-		{
-			icon=gtk_icon_theme_load_icon(icon_theme,"qgn_list_gene_default_app",40,0,NULL);
-		}
-		icon_image=gtk_image_new_from_pixbuf(icon);
-		g_object_unref(G_OBJECT(icon));
-		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),icon_image);
-		g_signal_connect(G_OBJECT(menu_item),"activate",G_CALLBACK(execute_command),-1);
-		gtk_menu_append(GTK_MENU_SHELL(plugin->menu),menu_item);
-	}
-    g_key_file_free(keyFile);
+		gtk_widget_show_all (plugin->menu);
+		g_signal_connect(G_OBJECT(plugin->menu), "hide", G_CALLBACK(menu_off), plugin);
+		g_free(filename);
 
-    /* Name the menu to get the appropriate theming */
-    gtk_widget_set_name (plugin->menu, "menu_from_navigator");
-
-    gtk_widget_show_all (plugin->menu);
-    g_signal_connect(G_OBJECT(plugin->menu), "hide", G_CALLBACK(menu_off), plugin);
-    g_free(filename);
-
-    gint width,height;
-    gtk_widget_set_size_request(plugin->menu,-1,-1);
-    avail_space(&width,&height,plugin);
-    gtk_widget_set_size_request(plugin->menu,width,height);
+		gint width,height;
+		avail_space(&width,&height,plugin);
+		gtk_widget_set_size_request(plugin->menu,-1,-1);
+		plugin->width=workarea.width;
+		plugin->height=workarea.height;
+		gtk_widget_set_size_request(plugin->menu,width,height);
 }
 
 gint dbus_req_handler(const gchar* interface, const gchar* method, GArray* arguments, PersonalMenuNavigatorPlugin *plugin, osso_rpc_t* retval)
@@ -580,7 +621,7 @@ gint dbus_req_handler(const gchar* interface, const gchar* method, GArray* argum
   osso_rpc_t val;
   val=g_array_index(arguments,osso_rpc_t,0);
   if (DBUS_TYPE_STRING==val.type)
-    gtk_button_clicked(GTK_BUTTON(plugin->button));
+   	gtk_button_clicked(GTK_BUTTON(plugin->button));
 
   return OSSO_OK;
 }
@@ -646,8 +687,8 @@ personal_menu_navigator_plugin_init (PersonalMenuNavigatorPlugin *navigator_plug
   navigator_plugin->menu=gtk_menu_new();
   create_menu(navigator_plugin);
 
-  navigator_plugin->context=osso_initialize("personalmenu","0.5",TRUE,NULL);
-  result=osso_rpc_set_cb_f(navigator_plugin->context,"com.nokia.personalmenu","/com/nokia/personalmenu","com.nokia.personalmenu",dbus_req_handler,navigator_plugin);
+  navigator_plugin->context=osso_initialize("personalmenu","0.9",TRUE,NULL);
+  result=osso_rpc_set_cb_f(navigator_plugin->context,"com.nokia.personalmenu","/com/nokia/personalmenu","com.nokia.personalmenu",&dbus_req_handler,navigator_plugin);
 
   conf_file = g_build_filename (g_get_home_dir (), ".personal_menu.rc", NULL);
   gnome_vfs_init();
